import { PromiseWithSubtest, TapPlugin, TestBase, TestBaseOpts } from '@tapjs/core';
import type { Test, TestOpts } from '@tapjs/test';
/**
 * Options added by this plugin
 *
 * @group Test Options
 */
export interface FilterOptions extends TestBaseOpts {
    /**
     * Set to true to run in contexts where `runOnly` is set
     */
    only?: boolean;
    /**
     * Only run subtests marked with { only: true }
     */
    runOnly?: boolean;
    /**
     * only run subtests whose name matches the supplied pattern.
     * Provide an array of strings/regexps to match down the test
     * heirarchy.
     */
    grep?: string | RegExp | (string | RegExp)[];
    /**
     * only run tests that DON'T match the pattern provided in `grep`
     */
    grepInvert?: boolean;
}
/**
 * Class that provides the {@link Filter#only} method, and extends the
 * {@link TestBase#shouldSkipChild} method to respect the grep option
 */
export declare class Filter {
    #private;
    constructor(t: TestBase, opts: FilterOptions);
    /**
     * Run a child test that will run when the `--only` config is set,
     * or `{ runOnly: true }` is set in the parent test options.
     */
    only(name: string, extra: TestOpts, cb: (t: Test) => any): PromiseWithSubtest<Test>;
    only(name: string, cb: (t: Test) => any): PromiseWithSubtest<Test>;
    only(extra: TestOpts, cb: (t: Test) => any): PromiseWithSubtest<Test>;
    only(cb: (t: Test) => any): PromiseWithSubtest<Test>;
}
/**
 * plugin method that instantiates a {@link Filter} object
 */
export declare const plugin: TapPlugin<Filter, FilterOptions>;
/**
 * Configuration options added by this plugin
 *
 * @group Configuration
 */
export declare const config: {
    only: {
        type: string;
        short: string;
        description: string;
    };
    grep: {
        type: string;
        multiple: boolean;
        hint: string;
        short: string;
        description: string;
    };
    invert: {
        type: string;
        short: string;
        description: string;
    };
    'no-invert': {
        type: string;
        short: string;
        description: string;
    };
};
//# sourceMappingURL=index.d.ts.map